@@ -26,13 +26,7 @@
 #include <utime.h>
 #include <string.h>
 
-#include <glib.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkmain.h>
-#include <gtk/gtklabel.h>
-#include <gtk/gtkprogressbar.h>
 #include <libedataserver/e-data-server-util.h>
 #include <e-util/e-folder-map.h>
 
@@ -47,6 +41,14 @@ CORBA_short maj=0;
 CORBA_short min=0;
 CORBA_short rev=0;
 
+#ifndef G_OS_WIN32
+
+/* No need for migration code from evolution-exchange 1.x on Win32.
+ * If and when the same code is partly used for migrating between
+ * future evolution-exchange versions, that code will have to be
+ * revised and ported as necessary.
+ */
+
 gchar *label_string = NULL;
 
 static void
@@ -449,6 +451,8 @@ migrate_common (gchar *src_path, const gchar *dest_path)
 	return ret;
 }
 
+#endif
+
 void
 exchange_migrate (const CORBA_short major,
 		  const CORBA_short minor,
@@ -464,7 +468,7 @@ exchange_migrate (const CORBA_short major,
 
 	/* FIXME: version check */
 	if (maj == 1 && min <= 5) {
-
+#ifndef G_OS_WIN32
 		if (!base_dir)
 			return;
 
@@ -507,5 +511,6 @@ exchange_migrate (const CORBA_short major,
 		if (ret == FALSE)
 			show_error_dialog ();
 
+#endif
 	}
 }
